@@ -1,7 +1,6 @@
 """Base class for all VeSync devices."""
 
 import logging
-import collections
 import json
 from typing import Optional, Union
 logger = logging.getLogger(__name__)
@@ -101,9 +100,9 @@ class VeSyncBaseDevice:
         ]
         if self.uuid is not None:
             disp.append(('UUID: ', self.uuid))
-        disp1 = collections.OrderedDict(disp)
-        for k, v in disp1.items():
-            print(f'{k:.<15} {v:<15}')
+
+        for line in disp:
+            print(f'{line[0]:.<30} {line[1]}')
 
     def displayJSON(self) -> str:  # pylint: disable=invalid-name
         """JSON API for device details."""
@@ -116,5 +115,5 @@ class VeSyncBaseDevice:
                 'Online': self.connection_status,
                 'Type': self.type,
                 'CID': self.cid,
-            }
-        )
+            },
+            indent=4)
