@@ -44,6 +44,14 @@ humid_features: dict = {
         'mist_levels': list(range(1, 10)),
         'warm_mist_levels': [0, 1, 2, 3]
     },
+    'OASISMIST': {
+            'module': 'VeSyncHumid200300S',
+            'models': ['LUH-O451S-WUS'],
+            'features': ['warm_mist'],
+            'mist_modes': ['humidity', 'sleep', 'manual'],
+            'mist_levels': list(range(1, 10)),
+            'warm_mist_levels': list(range(4))
+        },
 }
 
 
@@ -51,14 +59,14 @@ air_features: dict = {
     'Core200S': {
         'module': 'VeSyncAirBypass',
         'models': ['Core200S', 'LAP-C201S-AUSR', 'LAP-C202S-WUSR'],
-        'modes': ['sleep', 'off'],
+        'modes': ['sleep', 'off', 'manual'],
         'features': [],
         'levels': list(range(1, 4))
     },
     'Core300S': {
         'module': 'VeSyncAirBypass',
         'models': ['Core300S', 'LAP-C301S-WJP'],
-        'modes': ['sleep', 'off', 'auto'],
+        'modes': ['sleep', 'off', 'auto', 'manual'],
         'features': ['air_quality'],
         'levels': list(range(1, 5))
     },
@@ -68,7 +76,7 @@ air_features: dict = {
                    'LAP-C401S-WJP',
                    'LAP-C401S-WUSR',
                    'LAP-C401S-WAAA'],
-        'modes': ['sleep', 'off', 'auto'],
+        'modes': ['sleep', 'off', 'auto', 'manual'],
         'features': ['air_quality'],
         'levels': list(range(1, 5))
     },
@@ -78,7 +86,7 @@ air_features: dict = {
                    'LAP-C601S-WUS',
                    'LAP-C601S-WUSR',
                    'LAP-C601S-WEU'],
-        'modes': ['sleep', 'off', 'auto'],
+        'modes': ['sleep', 'off', 'auto', 'manual'],
         'features': ['air_quality'],
         'levels': list(range(1, 5))
     },
@@ -219,7 +227,7 @@ class VeSyncAirBypass(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
         if not isinstance(r, dict):
             logger.debug('Error in purifier response')
@@ -260,8 +268,6 @@ class VeSyncAirBypass(VeSyncBaseDevice):
                              speed, str(speeds))
                 return False
             new_speed = speed
-            if current_speed == new_speed:
-                return True
         else:
             if current_speed == speeds[-1]:
                 new_speed = speeds[0]
@@ -287,7 +293,7 @@ class VeSyncAirBypass(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -322,7 +328,7 @@ class VeSyncAirBypass(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -362,10 +368,16 @@ class VeSyncAirBypass(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(r):
+            if mode.lower() == 'manual':
+                self.speed = 1
+                self.mode = 'manual'
+            else:
+                self.mode = mode
+                self.speed = 0
             return True
         logger.debug('Error setting purifier mode')
         return False
@@ -414,7 +426,7 @@ class VeSyncAirBypass(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -451,7 +463,7 @@ class VeSyncAirBypass(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -485,7 +497,7 @@ class VeSyncAirBypass(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -545,7 +557,7 @@ class VeSyncAirBypass(VeSyncBaseDevice):
     def display(self) -> None:
         """Return formatted device info to stdout."""
         super().display()
-        disp1 = [
+        disp = [
             ('Mode: ', self.mode, ''),
             ('Filter Life: ', self.details['filter_life'], 'percent'),
             ('Fan Level: ', self.speed, ''),
@@ -557,13 +569,14 @@ class VeSyncAirBypass(VeSyncBaseDevice):
              self.config['display_forever'], '')
         ]
         if self.air_quality_feature:
-            disp1.extend([('Air Quality Level: ',
-                          self.details['air_quality'], ''),
-                          ('Air Quality Value: ',
-                           self.details['air_quality_value'], 'ug/m3')
-                          ])
-        for line in disp1:
-            print(f'{line[0]:.<20} {line[1]} {line[2]}')
+            disp.extend([
+                ('Air Quality Level: ',
+                    self.details['air_quality'], ''),
+                ('Air Quality Value: ',
+                    self.details['air_quality_value'], 'ug/m3')
+                ])
+        for line in disp:
+            print(f'{line[0]:.<30} {line[1]} {line[2]}')
 
     def displayJSON(self) -> str:
         """Return air purifier status and properties in JSON output."""
@@ -582,10 +595,13 @@ class VeSyncAirBypass(VeSyncBaseDevice):
             }
         )
         if self.air_quality_feature:
-            sup_val['Air Quality Level'] = str(self.details['air_quality'])
-            sup_val['Air Quality Value'] = str(
-                self.details['air_quality_value'])
-        return json.dumps(sup_val)
+            sup_val.update(
+                {'Air Quality Level': str(self.details['air_quality'])}
+            )
+            sup_val.update(
+                {'Air Quality Value': str(self.details['air_quality_value'])}
+            )
+        return json.dumps(sup_val, indent=4)
 
 
 class VeSyncAir131(VeSyncBaseDevice):
@@ -607,7 +623,7 @@ class VeSyncAir131(VeSyncBaseDevice):
             '/131airPurifier/v1/device/deviceDetail',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -632,7 +648,7 @@ class VeSyncAir131(VeSyncBaseDevice):
             '/131airpurifier/v1/device/configurations',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -679,7 +695,7 @@ class VeSyncAir131(VeSyncBaseDevice):
 
             r, _ = Helpers.call_api(
                 '/131airPurifier/v1/device/deviceStatus', 'put',
-                json=body, headers=head
+                json_object=body, headers=head
             )
 
             if r is not None and Helpers.code_check(r):
@@ -699,7 +715,7 @@ class VeSyncAir131(VeSyncBaseDevice):
 
             r, _ = Helpers.call_api(
                 '/131airPurifier/v1/device/deviceStatus', 'put',
-                json=body, headers=head
+                json_object=body, headers=head
             )
 
             if r is not None and Helpers.code_check(r):
@@ -761,7 +777,7 @@ class VeSyncAir131(VeSyncBaseDevice):
 
         r, _ = Helpers.call_api(
             '/131airPurifier/v1/device/updateSpeed', 'put',
-            json=body, headers=head
+            json_object=body, headers=head
         )
 
         if r is not None and Helpers.code_check(r):
@@ -782,7 +798,7 @@ class VeSyncAir131(VeSyncBaseDevice):
 
             r, _ = Helpers.call_api(
                 '/131airPurifier/v1/device/updateMode', 'put',
-                json=body, headers=head
+                json_object=body, headers=head
             )
 
             if r is not None and Helpers.code_check(r):
@@ -799,7 +815,7 @@ class VeSyncAir131(VeSyncBaseDevice):
     def display(self) -> None:
         """Return formatted device info to stdout."""
         super().display()
-        disp1 = [
+        disp = [
             ('Active Time : ', self.active_time, ' minutes'),
             ('Fan Level: ', self.fan_level, ''),
             ('Air Quality: ', self.air_quality, ''),
@@ -807,8 +823,8 @@ class VeSyncAir131(VeSyncBaseDevice):
             ('Screen Status: ', self.screen_status, ''),
             ('Filter Life: ', json.dumps(self.filter_life), ' percent')
             ]
-        for line in disp1:
-            print(f'{line[0]:.<15} {line[1]} {line[2]}')
+        for line in disp:
+            print(f'{line[0]:.<30} {line[1]} {line[2]}')
 
     def displayJSON(self) -> str:
         """Return air purifier status and properties in JSON output."""
@@ -824,7 +840,7 @@ class VeSyncAir131(VeSyncBaseDevice):
                 'Filter Life': str(self.filter_life)
             }
         )
-        return sup_val
+        return json.dumps(sup_val, indent=4)
 
 
 class VeSyncHumid200300S(VeSyncBaseDevice):
@@ -944,7 +960,7 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
         if r is None or not isinstance(r, dict):
             logger.debug("Error getting status of %s ", self.device_name)
@@ -993,7 +1009,7 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -1041,7 +1057,7 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -1068,7 +1084,7 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -1102,7 +1118,7 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -1132,7 +1148,7 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -1159,7 +1175,7 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -1197,7 +1213,7 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -1247,7 +1263,7 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
@@ -1293,7 +1309,7 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
     def display(self) -> None:
         """Return formatted device info to stdout."""
         super().display()
-        disp1 = [
+        disp = [
             ('Mode: ', self.details['mode'], ''),
             ('Humidity: ', self.details['humidity'], 'percent'),
             ('Mist Virtual Level: ', self.details['mist_virtual_level'], ''),
@@ -1309,15 +1325,15 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
             ('Automatic Stop: ', self.config['automatic_stop'], ''),
         ]
         if self.night_light:
-            disp1.append(('Night Light Brightness: ',
-                          self.details['night_light_brightness'], 'percent'))
+            disp.append(('Night Light Brightness: ',
+                         self.details['night_light_brightness'], 'percent'))
         if self.warm_mist_feature:
-            disp1.append(('Warm mist enabled: ',
-                          self.details['warm_mist_enabled'], ''))
-            disp1.append(('Warm mist level: ',
-                          self.details['warm_mist_level'], ''))
-        for line in disp1:
-            print(f'{line[0]:.<29} {line[1]} {line[2]}')
+            disp.append(('Warm mist enabled: ',
+                         self.details['warm_mist_enabled'], ''))
+            disp.append(('Warm mist level: ',
+                         self.details['warm_mist_level'], ''))
+        for line in disp:
+            print(f'{line[0]:.<30} {line[1]} {line[2]}')
 
     def displayJSON(self) -> str:
         """Return air purifier status and properties in JSON output."""
@@ -1347,7 +1363,7 @@ class VeSyncHumid200300S(VeSyncBaseDevice):
         if self.warm_mist_feature:
             sup_val['Warm mist enabled'] = self.details['warm_mist_enabled']
             sup_val['Warm mist level'] = self.details['warm_mist_level']
-        return json.dumps(sup_val)
+        return json.dumps(sup_val, indent=4)
 
 
 class VeSyncHumid200S(VeSyncHumid200300S):
@@ -1377,10 +1393,10 @@ class VeSyncHumid200S(VeSyncHumid200300S):
             '/cloud/v2/deviceManaged/bypassV2',
             method='post',
             headers=head,
-            json=body,
+            json_object=body,
         )
 
         if r is not None and Helpers.code_check(r):
             return True
-        logger.debug("Error toggling 300S display - %s", self.device_name)
+        logger.debug("Error toggling 200S display - %s", self.device_name)
         return False
